@@ -112,6 +112,7 @@ mcmc_hist <- function(x,
                       facet_args = list(),
                       ...,
                       binwidth = NULL,
+                      breaks = NULL,
                       freq = TRUE) {
   check_ignored_arguments(...)
   .mcmc_hist(
@@ -121,6 +122,7 @@ mcmc_hist <- function(x,
     transformations = transformations,
     facet_args = facet_args,
     binwidth = binwidth,
+    breaks = breaks,
     by_chain = FALSE,
     freq = freq,
     ...
@@ -241,9 +243,10 @@ mcmc_dens_chains <- function(x, pars = character(), regex_pars = character(),
     scale_y_discrete(limits = unique(rev(data$parameter)),
                      expand = c(0.05, .6)) +
     scale_color +
+    bayesplot_theme_get() +
     yaxis_title(FALSE) +
     xaxis_title(FALSE) +
-    grid_lines_y(color = "gray90")  +
+    grid_lines_y(color = "gray90") +
     theme(axis.text.y = element_text(hjust = 1, vjust = 0))
 }
 
@@ -306,6 +309,7 @@ mcmc_violin <- function(x,
                       transformations = list(),
                       facet_args = list(),
                       binwidth = NULL,
+                      breaks = NULL,
                       by_chain = FALSE,
                       freq = TRUE,
                       ...) {
@@ -322,7 +326,8 @@ mcmc_violin <- function(x,
       color = get_color("mid_highlight"),
       size = .25,
       na.rm = TRUE,
-      binwidth = binwidth
+      binwidth = binwidth,
+      breaks = breaks
     )
 
   if (is.null(facet_args[["scales"]]))
@@ -345,6 +350,7 @@ mcmc_violin <- function(x,
 
   graph +
     dont_expand_y_axis(c(0.005, 0)) +
+    bayesplot_theme_get() +
     yaxis_text(FALSE) +
     yaxis_title(FALSE) +
     yaxis_ticks(FALSE) +
@@ -401,8 +407,8 @@ mcmc_violin <- function(x,
     geom_args[["color"]] <- get_color("mid_highlight")
   }
 
-  graph <- ggplot(data, mapping = do.call("aes_", aes_mapping)) +
-    do.call(geom_fun, geom_args)
+  graph <- ggplot(data, mapping = do.call("aes_", aes_mapping))  +
+      do.call(geom_fun, geom_args)
 
   if (!violin) {
     graph <- graph + dont_expand_x_axis()
@@ -433,6 +439,7 @@ mcmc_violin <- function(x,
 
   graph +
     dont_expand_y_axis(c(0.005, 0)) +
+    bayesplot_theme_get() +
     yaxis_text(FALSE) +
     yaxis_ticks(FALSE) +
     yaxis_title(on = n_param == 1 && violin) +
