@@ -204,6 +204,11 @@ mcmc_hex <- function(x,
 #'   \code{off_diag_fun} is \code{"scatter"} then \code{off_diag_args} could
 #'   include optional arguments to \code{mcmc_scatter} like \code{size} and
 #'   \code{alpha}.
+#' @param grid_args,save_gg_objects For \code{mcmc_pairs}, arguments to pass to
+#'   \code{\link{bayesplot_grid}}. For example, since \code{mcmc_pairs} returns
+#'   more than a single ggplot object, using \code{\link{ggtitle}} afterwards
+#'   will not work. But you you can still add a title to the plot using
+#'   \code{grid_args = list(top="My title")}.
 #'
 #' @examples
 #' \donttest{
@@ -253,8 +258,8 @@ mcmc_hex <- function(x,
 #' mcmc_scatter(posterior, pars = c("sigma", "(Intercept)"),
 #'              np = np, np_style = div_style)
 #'
-#' # split the draws according to above/below median accept_stat__ and
-#' # show approximate location of divergences (red points)
+#' # split the draws according to above/below median accept_stat__
+#' # and show approximate location of divergences (red points)
 #' color_scheme_set("brightblue")
 #' mcmc_pairs(
 #'   posterior,
@@ -300,7 +305,9 @@ mcmc_pairs <- function(x,
                        lp = NULL,
                        np = NULL,
                        np_style = pairs_style_np(),
-                       max_treedepth = NULL) {
+                       max_treedepth = NULL,
+                       grid_args = list(),
+                       save_gg_objects = TRUE) {
   check_ignored_arguments(...)
 
   stopifnot(
@@ -320,10 +327,12 @@ mcmc_pairs <- function(x,
   n_param <- num_params(x)
   pars <- parameter_names(x)
 
-  if (n_chain == 1)
+  if (n_chain == 1) {
     warning("Only one chain in 'x'. This plot is more useful with multiple chains.")
-  if (n_param < 2)
+  }
+  if (n_param < 2) {
     stop("This plot requires at least two parameters in 'x'.")
+  }
 
   no_np <- is.null(np)
   no_lp <- is.null(lp)
@@ -413,7 +422,10 @@ mcmc_pairs <- function(x,
   plots <- lapply(plots, function(x)
     x + xaxis_title(FALSE) + yaxis_title(FALSE))
 
-  bayesplot_grid(plots = plots, legends = FALSE)
+  bayesplot_grid(plots = plots,
+                 legends = FALSE,
+                 grid_args = grid_args,
+                 save_gg_objects = save_gg_objects)
 }
 
 
@@ -665,7 +677,8 @@ pairs_condition <- function(chains = NULL, draws = NULL, nuts = NULL) {
     xydata <- dplyr::filter(xydata, UQ(divg) == 0)
   }
 
-  graph <- ggplot(data = xydata, aes_(x = ~ x, y = ~ y))
+  graph <- ggplot(data = xydata, aes_(x = ~ x, y = ~ y)) +
+    bayesplot_theme_get()
 
   if (!hex) { # scatterplot
     graph <- graph +
