@@ -121,6 +121,7 @@ ppc_error_hist <-
            yrep,
            ...,
            binwidth = NULL,
+           breaks = NULL,
            freq = TRUE) {
     check_ignored_arguments(...)
 
@@ -143,8 +144,10 @@ ppc_error_hist <-
         fill = get_color("l"),
         color = get_color("lh"),
         size = 0.25,
-        binwidth = binwidth
+        binwidth = binwidth,
+        breaks = breaks
       ) +
+      bayesplot_theme_get() +
       xlab(expression(italic(y) - italic(y)[rep])) +
       dont_expand_y_axis() +
       force_axes_in_facets() +
@@ -166,6 +169,7 @@ ppc_error_hist_grouped <-
            group,
            ...,
            binwidth = NULL,
+           breaks = NULL,
            freq = TRUE) {
     check_ignored_arguments(...)
 
@@ -179,9 +183,11 @@ ppc_error_hist_grouped <-
         fill = get_color("l"),
         color = get_color("lh"),
         size = 0.25,
-        binwidth = binwidth
+        binwidth = binwidth,
+        breaks = breaks
       ) +
       facet_grid(rep_id ~ group, scales = "free") +
+      bayesplot_theme_get() +
       xlab(expression(italic(y) - italic(y)[rep])) +
       dont_expand_y_axis(c(0.005, 0)) +
       force_axes_in_facets() +
@@ -375,7 +381,8 @@ ppc_error_binned <- function(y, yrep, ..., size = 1, alpha = 0.25) {
     labs(
       x = "Predicted proportion",
       y = "Average Errors \n (with 2SE bounds)"
-    )
+    ) +
+    bayesplot_theme_get()
 
   if (n > 1)
     graph <- graph +
