@@ -35,23 +35,33 @@ test_that("ppc_intervals_data returns correct structure", {
   d <- ppc_intervals_data(y, yrep, x = 1:length(y), prob = .9)
   d_group <- ppc_intervals_data(y, yrep, x, group)
   expect_named(d, c("y_id", "y_obs", "x",
-                    "prob", "lo", "mid", "hi"))
+                    "outer_width", "inner_width",
+                    "ll", "l", "m", "h", "hh"))
   expect_named(d_group, c("y_id", "y_obs", "group", "x",
-                          "prob", "lo", "mid", "hi"))
+                          "outer_width", "inner_width",
+                          "ll", "l", "m", "h", "hh"))
 
   expect_error(
     ppc_intervals_data(y, yrep, x = 1:length(y), prob = 0), "prob")
 
   expect_error(
     ppc_intervals_data(y, yrep, x = 1:length(y), prob = 1.01), "prob")
+
+  expect_error(
+    ppc_intervals_data(y, yrep, x = 1:length(y), prob_outer = 0), "prob_outer")
+
+  expect_error(
+    ppc_intervals_data(y, yrep, x = 1:length(y), prob_outer = 1.01), "prob_outer")
 })
 
 test_that("ppc_intervals_data does math correctly", {
-  d <- ppc_intervals_data(y, yrep, prob = .9)
-  qs <- unname(quantile(yrep[, 1], c(.05, .5, .95)))
-  expect_equal(d$lo[1], qs[1])
-  expect_equal(d$mid[1], qs[2])
-  expect_equal(d$hi[1], qs[3])
+  d <- ppc_intervals_data(y, yrep, prob = .4, prob_outer = .8)
+  qs <- unname(quantile(yrep[, 1], c(.1, .3, .5, .7, .9)))
+  expect_equal(d$ll[1], qs[1])
+  expect_equal(d$l[1],  qs[2])
+  expect_equal(d$m[1],  qs[3])
+  expect_equal(d$h[1],  qs[4])
+  expect_equal(d$hh[1], qs[5])
 
   # Testing groups and known quantiles
   y <- rep(10, 4)
@@ -60,11 +70,14 @@ test_that("ppc_intervals_data does math correctly", {
   yrep_g2 <- yrep_g1 - 10
   yrep <- cbind(yrep_g1, yrep_g2)
 
-  d <- ppc_intervals_data(y, yrep, group = group, prob = .9)
-  expect_equal(unique(d$prob), .9)
-  expect_equal(d$lo,  c( 1,  1, -9, -9))
-  expect_equal(d$mid, c(10, 10,  0,  0))
-  expect_equal(d$hi,  c(19, 19,  9,  9))
+  d <- ppc_intervals_data(y, yrep, group = group, prob = .5, prob_outer = .9)
+  expect_equal(unique(d$inner_width), .5)
+  expect_equal(unique(d$outer_width), .9)
+  expect_equal(d$ll, c( 1,  1, -9, -9))
+  expect_equal(d$l,  c( 5,  5, -5, -5))
+  expect_equal(d$m,  c(10, 10,  0,  0))
+  expect_equal(d$h,  c(15, 15,  5,  5))
+  expect_equal(d$hh, c(19, 19,  9,  9))
 })
 
 
